@@ -4,7 +4,7 @@ The key principle: avoid building the app around GUI. Make it easy to add GUI to
 """
 import unittest
 
-import logging_config
+from yadraw import logging_config
 import yadraw as yd
 import time
 
